I hereby claim:
- I am brgmnn on github.
- I am bergmann (https://keybase.io/bergmann) on keybase.
- I have a public key ASD7kzbPtSPvQ_AT4ygchl6tJ_OwuOSyZw3RZ6XBiMvQIAo
To claim this, I am signing this object:
| #!/bin/sh | |
| # Project identifier. This will be either the child technical task identifier or for new tickets | |
| # the project code. | |
| PROJECT=PROJ | |
| case "$2" in | |
| merge);; | |
| squash);; | |
| template);; |
I hereby claim:
To claim this, I am signing this object:
| $include "volutils.cl" | |
| __kernel void mol_overlap_AB(__global const Atom * atoms0,__global const Atom * atoms1, __global const short * anat0, | |
| __global const short * anat1, __global const ConfInfo * cinfo, __global Orientation * orientations, | |
| __global float * vsimRaw, const unsigned int maxgid) { | |
| // get global id for this kernel | |
| const int gid = get_global_id(0); | |
| if(gid >= maxgid) { | |
| return; |
| # This plots tours of two trucks around the depot and customers. | |
| # Execute it from the command prompt with "gnuplot plot-trucks". | |
| # First you need to create the tours in the first truck1.txt and truck2.txt. | |
| set terminal png | |
| # Increase size of symbols from default - only needed for on-screen viewing. | |
| set pointsize 1 | |
| # Expand range of x-axis beyond minimum needed to plot file |
| #!/usr/bin/python | |
| import sys | |
| import os | |
| import math | |
| import subprocess | |
| # how many samples you want to average over. | |
| n = 20 | |
| # basic statistic functions |